==> cnn-hapi-2.4.1.tgz: package/lib/reg-test.js <==
'use strict';

const Boom = require('boom');
const util = require('util');



class Registry {
    constructor(config, pkg) {
        this.config     = config;
        this._map       = {};
        this.pkg        = pkg;
        this._registry  = [];
    }

    getPackage(pkg) {
        const spawn = require('child_process').spawn;

        return new Promise((resolve, reject) => {
            const npmi = spawn('npm', ['install', `${pkg}`, '-E'], {stdio: 'inherit'});

            //return (npmi.status === 0) ? resolve(npmi.status) : reject(Boom.internal(`Internal error: ${error}`));
            npmi.stdout.on('data', data => console.log(data));
            npmi.stderr.on('data', data => console.log('error: ', data));
            npmi.on('exit', exitCode => {
                return (exitCode === 0) ? resolve(Number(exitCode)) : reject(Boom.internal(`Internal error: ${error}`));
            });
        });
    }

    // set the registry map
    register(key, options) {

        if (key in this._map) {
            console.log(util.format('Object with key %s already exists in the Registry', key));
            return;
        }
        this._map[key] = options;
    }

    registerVision() {
        return this.getPackage('vision').then((response, reject) => {
            console.log('vision response', response);
            this.register('vision', {options: {}});
        }, error => reject(error));
    }

    registerDefaults(userOptions) {
        const promises = new Map(require('lodash').toPairs(userOptions).filter(v => v[0] !== undefined && v[1]));

        console.log(promises);
        this.register('inert', {options: {}});
        //return new Promise.all()

        /* const registerConfig = [
            {swagger: this.config.withSwagger},
            {vision: this.config.withSwagger || this.config.withHandlebars}
        ];*/

        return new Promise((resolve, reject) => {

            (this.config.withSwagger || this.config.withHandlebars) && this.registerVision();
            if (this.config.withSwagger) {
                this.register('hapi-swagger', {options: {
                    info: {
                        description: this.config.description,
                        contact: {
                            email: this.config.contactEmail,
                            name: this.config.contactName,
                            url: this.config.contactUrl
                        },
                        license: {
                            name: this.config.licenseName,
                            url: this.config.licenseUrl
                        },
                        termsOfService: this.config.termsOfService,
                        title: this.config.name,
                        version: this.pkg.version
                    }
                }});
            }

            if (this.config.withGoodConsole) {
                this.register('good', {options: {
                    ops: {interval: 5000}, reporters: {
                        console: [{module: 'good-squeeze', name: 'Squeeze',
                            args: [{log: '*', ops: '*', response: '*'}]
                        }, {
                            module: 'good-console'
                        }, 'stdout']
                    }
                }});
            }

            resolve('hi');
        });
    }

    // require each plugin
    get bundle() {
        var obj,
            plugin;

        for (let b in this._map) {
            obj  = Object.create(null);
            plugin = Object.defineProperties(obj, {
                register: {value: require(b), enumerable: true, writable: true},
                options: {value: this._map[b].options, enumerable: true}
            });

            this._registry.push(plugin);
        }

        return this._registry;
    }
}

module.exports = Registry;

==> cnn-hapi-2.4.3.tgz: package/lib/reg-test.js <==
'use strict';

const Boom = require('boom');
const util = require('util');



class Registry {
    constructor(config, pkg) {
        this.config     = config;
        this._map       = {};
        this.pkg        = pkg;
        this._registry  = [];
    }

    getPackage(pkg) {
        const spawn = require('child_process').spawn;

        return new Promise((resolve, reject) => {
            const npmi = spawn('npm', ['install', `${pkg}`, '-E'], {stdio: 'inherit'});

            //return (npmi.status === 0) ? resolve(npmi.status) : reject(Boom.internal(`Internal error: ${error}`));
            npmi.stdout.on('data', data => console.log(data));
            npmi.stderr.on('data', data => console.log('error: ', data));
            npmi.on('exit', exitCode => {
                return (exitCode === 0) ? resolve(Number(exitCode)) : reject(Boom.internal(`Internal error: ${error}`));
            });
        });
    }

    // set the registry map
    register(key, options) {

        if (key in this._map) {
            console.log(util.format('Object with key %s already exists in the Registry', key));
            return;
        }
        this._map[key] = options;
    }

    registerVision() {
        return this.getPackage('vision').then((response, reject) => {
            console.log('vision response', response);
            this.register('vision', {options: {}});
        }, error => reject(error));
    }

    registerDefaults(userOptions) {
        const promises = new Map(require('lodash').toPairs(userOptions)
            .filter(v => v[0] !== undefined && v[1]));

        console.log(promises);
        this.register('inert', {options: {}});
        //return new Promise.all()

        /* const registerConfig = [
            {swagger: this.config.withSwagger},
            {vision: this.config.withSwagger || this.config.withHandlebars}
        ];*/

        return new Promise((resolve, reject) => {

            (this.config.withSwagger || this.config.withHandlebars) && this.registerVision();
            if (this.config.withSwagger) {
                this.register('hapi-swagger', {options: {
                    info: {
                        description: this.config.description,
                        contact: {
                            email: this.config.contactEmail,
                            name: this.config.contactName,
                            url: this.config.contactUrl
                        },
                        license: {
                            name: this.config.licenseName,
                            url: this.config.licenseUrl
                        },
                        termsOfService: this.config.termsOfService,
                        title: this.config.name,
                        version: this.pkg.version
                    }
                }});
            }

            if (this.config.withGoodConsole) {
                this.register('good', {options: {
                    ops: {interval: 5000}, reporters: {
                        console: [{module: 'good-squeeze', name: 'Squeeze',
                            args: [{log: '*', ops: '*', response: '*'}]
                        }, {
                            module: 'good-console'
                        }, 'stdout']
                    }
                }});
            }

            resolve('hi');
        });
    }

    // require each plugin
    get bundle() {
        var obj,
            plugin;

        for (let b in this._map) {
            obj  = Object.create(null);
            plugin = Object.defineProperties(obj, {
                register: {value: require(b), enumerable: true, writable: true},
                options: {value: this._map[b].options, enumerable: true}
            });

            this._registry.push(plugin);
        }

        return this._registry;
    }
}

module.exports = Registry;
